"use strict";

exports.__esModule = true;
exports.isFlexProp = isFlexProp;
exports.display = display;
exports.flex = flex;
exports.flexWrap = flexWrap;
exports.alignItems = alignItems;
exports.alignSelf = alignSelf;
exports.flexDirection = flexDirection;
exports.justifyContent = justifyContent;
var BOX_ALIGN = {
  stretch: 'stretch',
  'flex-start': 'start',
  'flex-end': 'end',
  center: 'center'
};
var BOX_ORIENT = {
  row: 'horizontal',
  column: 'vertical'
};
var BOX_PACK = {
  'flex-start': 'start',
  'flex-end': 'end',
  center: 'center',
  'space-between': 'justify',
  'space-around': 'justify' // Just same as `space-between`

};
var FLEX_PROPS = {
  display: true,
  flex: true,
  alignItems: true,
  alignSelf: true,
  flexDirection: true,
  justifyContent: true,
  flexWrap: true
};

function isFlexProp(prop) {
  return FLEX_PROPS[prop];
}

function display(value, style) {
  if (style === void 0) {
    style = {};
  }

  if (value === 'flex') {
    style.display = ['-webkit-box', '-webkit-flex', 'flex'];
  } else {
    style.display = value;
  }

  return style;
}

function flex(value, style) {
  if (style === void 0) {
    style = {};
  }

  style.webkitBoxFlex = value;
  style.webkitFlex = value;
  style.flex = value;
  return style;
}

function flexWrap(value, style) {
  if (style === void 0) {
    style = {};
  }

  style.webkitFlexWrap = value;
  style.flexWrap = value;
  return style;
}

function alignItems(value, style) {
  if (style === void 0) {
    style = {};
  }

  style.webkitBoxAlign = BOX_ALIGN[value];
  style.webkitAlignItems = value;
  style.alignItems = value;
  return style;
}

function alignSelf(value, style) {
  if (style === void 0) {
    style = {};
  }

  style.webkitAlignSelf = value;
  style.alignSelf = value;
  return style;
}

function flexDirection(value, style) {
  if (style === void 0) {
    style = {};
  }

  style.webkitBoxOrient = BOX_ORIENT[value];
  style.webkitFlexDirection = value;
  style.flexDirection = value;
  return style;
}

function justifyContent(value, style) {
  if (style === void 0) {
    style = {};
  }

  style.webkitBoxPack = BOX_PACK[value];
  style.webkitJustifyContent = value;
  style.justifyContent = value;
  return style;
}